@@ -5,94 +5,102 @@ use Carp;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw/
-		       $char_const_re
-		       $comment_re
-		       $cpp_re
-		       $cvar_re
-		       $cxx_comment_re
-		       $decimal_re
-		       $fargs_re
-		       $grammar_re
-		       $hex_re
-		       $include
-		       $include_local
-		       $number_re
-		       $octal_re
-		       $operator_re
-		       $reserved_re
-		       $single_string_re
-		       $string_re
-		       $trad_comment_re
-		       $word_re
-		       @fields
-		       decomment
-		       function_arg
-		       remove_quotes
-		       strip_comments
-		       tokenize
-		   /;
+    $char_const_re
+    $comment_re
+    $cpp_re
+    $cvar_re
+    $cxx_comment_re
+    $decimal_re
+    $fargs_re
+    $grammar_re
+    $hex_re
+    $include
+    $include_local
+    $number_re
+    $octal_re
+    $operator_re
+    $reserved_re
+    $single_string_re
+    $string_re
+    $trad_comment_re
+    $word_re
+    @fields
+    decomment
+    function_arg
+    strip_comments
+    tokenize
+/;
 
 our %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 # http://www.open-std.org/JTC1/SC22/WG14/www/docs/n1256.pdf
 # 6.4.1
 
 my @reserved_words = sort {length $b <=> length $a} 
 qw/
-auto
-break
-case
-char
-const
-continue
-default
-do
-double
-else
-enum
-extern
-float
-for
-goto
-if
-inline
-int
-long
-register
-restrict
-return
-short
-signed
-sizeof
-static
-struct
-switch
-typedef
-union
-unsigned
-void
-volatile
-while
-_Bool
-_Complex
-_Imaginary
+    auto
+    break
+    case
+    char
+    const
+    continue
+    default
+    do
+    double
+    else
+    enum
+    extern
+    float
+    for
+    goto
+    if
+    inline
+    int
+    long
+    register
+    restrict
+    return
+    short
+    signed
+    sizeof
+    static
+    struct
+    switch
+    typedef
+    union
+    unsigned
+    void
+    volatile
+    while
+    _Bool
+    _Complex
+    _Imaginary
 /;
 
 my $reserved_words = join '|', @reserved_words;
 our $reserved_re = qr/\b(?:$reserved_words)\b/;
 
-our @fields = qw/comment cpp char_const operator grammar 
-                 number word string reserved/;
+our @fields = qw/
+    char_const
+    comment
+    cpp
+    grammar 
+    number
+    operator
+    reserved
+    string
+    word
+/;
 
 # Regular expression to match a /* */ C comment.
 
 our $trad_comment_re = qr!
-                            /\*
-                            (?:
+    /\*
+    (?:
                                 # Match "not an asterisk"
                                 [^*]
                             |
@@ -104,7 +112,7 @@ our $trad_comment_re = qr!
                             # Match multiple asterisks followed by a
                             # slash.
                             \*+/
-                        !x;
+!x;
 
 # Regular expression to match a // C comment (C++-style comment).
 
@@ -113,40 +121,40 @@ our $cxx_comment_re = qr!//.*\n!;
 # Master comment regex
 
 our $comment_re = qr/
-                       (?:
-                           $trad_comment_re
-                       |
-                           $cxx_comment_re
-                       )
-                   /x;
+    (?:
+	$trad_comment_re
+    |
+	$cxx_comment_re
+    )
+/x;
 
 # Regular expression to match a C preprocessor instruction.
 
 our $cpp_re = qr/^\h*
                  \#
                  (?:
-                    $trad_comment_re
-                |
-                    [^\\\n]
-                |
-                    \\[^\n]
-                |
-                    \\\n
-                )+\n
-               /mx;
+		     $trad_comment_re
+		 |
+		     [^\\\n]
+		 |
+		     \\[^\n]
+		 |
+		     \\\n
+		 )+\n
+/mx;
 
 # Regular expression to match a C character constant like 'a' or '\0'.
 # This allows any \. expression at all.
 
 our $char_const_re = qr/
-                          '
-                          (?:
-                              .
-                          |
-                              \\.
-                          )
-                          '
-                      /x;
+    '
+    (?:
+	.
+    |
+	\\.
+    )
+    '
+/x;
 
 # Regular expression to match one character operators
 
@@ -155,18 +163,18 @@ our $one_char_op_re = qr/(?:\%|\&|\+|\-|\=|\/|\||\.|\*|\:|>|<|\!|\?|~|\^)/;
 # Regular expression to match all operators
 
 our $operator_re = qr/
-                        (?:
-                                # Operators with two characters
-                                \|\||&&|<<|>>|--|\+\+|->|==
-                            |
-                                # Operators with one or two characters
-                                # followed by an equals sign.
-                                (?:<<|>>|\+|-|\*|\/|%|&|\||\^)
-                                =
-                            |
-                                $one_char_op_re
-                            )
-                    /x;
+    (?:
+	# # Operators with two characters # 
+	\|\||&&|<<|>>|--|\+\+|->|==
+    |
+	# Operators with one or two characters
+	# followed by an equals sign.
+	(?:<<|>>|\+|-|\*|\/|%|&|\||\^)
+	=
+    |
+	$one_char_op_re
+    )
+/x;
 
 # Re to match a C number
 
@@ -177,14 +185,14 @@ our $decimal_re = qr/[-+]?([0-9]*\.)?[0-9]+([eE][-+]?[0-9]+)?l?/i;
 our $hex_re = qr/0x[0-9a-f]+l?/i;
 
 our $number_re = qr/
-                      (?:
-                          $hex_re
-                      |
-                          $decimal_re
-		      |
-			  $octal_re
-                      )
-                  /x;
+    (?:
+	$hex_re
+    |
+	$decimal_re
+    |
+	$octal_re
+    )
+/x;
 
 # Re to match a C word
 
@@ -197,12 +205,12 @@ our $grammar_re = qr/[(){};,\[\]]/;
 # Regular expression to match a C string.
 
 our $single_string_re = qr/
-                             (?:
-                                 "
-                                 (?:[^\\"]+|\\[^"]|\\")*
-                                 "
-                             )
-                         /x;
+    (?:
+	"
+	(?:[^\\"]+|\\[^"]|\\")*
+	"
+    )
+/x;
 
 
 # Compound string regular expression.
@@ -213,27 +221,27 @@ our $string_re = qr/$single_string_re(?:\s*$single_string_re)*/;
 # captures.
     
 our $c_re = qr/
-                 (?<leading>\s+)?
-                 (?:
-                     (?<comment>$comment_re)
-                 |
-                     (?<cpp>$cpp_re)
-                 |
-                     (?<char_const>$char_const_re)
-                 |
-                     (?<operator>$operator_re)
-                 |
-                     (?<grammar>$grammar_re)
-                 |
-                     (?<number>$number_re)
-                 |
-                     (?<reserved>$reserved_re)
-                 |
-                     (?<word>$word_re)
-                 |
-                     (?<string>$string_re)
-                 )
-             /x;
+    (?<leading>\s+)?
+    (?:
+	(?<comment>$comment_re)
+    |
+	(?<cpp>$cpp_re)
+    |
+	(?<char_const>$char_const_re)
+    |
+	(?<operator>$operator_re)
+    |
+	(?<grammar>$grammar_re)
+    |
+	(?<number>$number_re)
+    |
+	(?<reserved>$reserved_re)
+    |
+	(?<word>$word_re)
+    |
+	(?<string>$string_re)
+    )
+/x;
 
 
 # Match for '#include "file.h"'. This captures the entire #include
@@ -337,8 +345,6 @@ sub tokenize
     # This array contains array references, each of which is a pair of
     # start and end points of a line in $text.
 
-    my @lines = get_lines ($text);
-
     # The tokens the input is broken into.
 
     my @tokens;
@@ -455,7 +461,10 @@ sub strip_comments
     # are deleted before C++ comments, see below for explanation.
     while ($xs =~ /($single_string_re|$trad_comment_re|$cxx_comment_re)/g) {
         my $comment = $1;
-	if ($comment =~ /^".*"$/) {
+	# The /s regex qualifier is necessary because
+	# $single_string_re can match newlines within the
+	# quotes. 2025-08-05
+	if ($comment =~ /^".*"$/s) {
 	    next;
 	}
 	# If the C comment consists of int/* comment */x;, it compiles
